@@ -20,7 +20,7 @@
 
 #include <FFDec.hpp>
 
-class FFDecHWAccel : public FFDec
+class FFMPEG_EXPORT FFDecHWAccel : public FFDec
 {
 protected:
     FFDecHWAccel();
@@ -39,4 +39,5 @@ protected:
 protected:
     bool m_hasCriticalError = false;
     bool m_hasHWDecContext = false;
+    SwsContext *m_swsCtx = nullptr;
 };
