@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2022  Błażej Szczygieł
+    Copyright (C) 2010-2023  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -30,4 +30,30 @@ public:
 private:
     QList<Info> getModulesInfo(const bool) const override;
     void *createInstance(const QString &) override;
+
+    SettingsWidget *getSettingsWidget() override;
+
+private:
+    bool m_fullScreen = false;
+};
+
+/**/
+
+class QDoubleSpinBox;
+class QCheckBox;
+
+class ModuleSettingsWidget final : public Module::SettingsWidget
+{
+    Q_DECLARE_TR_FUNCTIONS(ModuleSettingsWidget)
+
+public:
+    ModuleSettingsWidget(Module &module);
+
+private:
+    void saveSettings() override;
+
+private:
+    QDoubleSpinBox *const m_minFpsSpinBox;
+    QDoubleSpinBox *const m_maxFpsSpinBox;
+    QCheckBox *const m_onlyFullScreenCheckBox;
 };
