@@ -26,18 +26,16 @@
 #include <QMPlay2OSD.hpp>
 
 #include <QOpenGLShaderProgram>
+#include <QOpenGLFunctions_1_5>
+#include <QOpenGLExtraFunctions>
 
 #include <QCoreApplication>
 #include <QImage>
 #include <QTimer>
 
-#if !defined OPENGL_ES2 && !defined Q_OS_MACOS
-    #include <GL/glext.h>
-#endif
-
 class OpenGLHWInterop;
 
-class OpenGLCommon : public VideoOutputCommon
+class OpenGLCommon : public VideoOutputCommon, public QOpenGLExtraFunctions
 {
     Q_DECLARE_TR_FUNCTIONS(OpenGLCommon)
 
@@ -78,23 +76,16 @@ public:
 
     bool setSphericalView(bool spherical) override;
 protected:
-    static void setTextureParameters(GLenum target, quint32 texture, GLint param);
+    void setTextureParameters(GLenum target, quint32 texture, GLint param);
 
     void initializeGL();
     void paintGL();
 
     void contextAboutToBeDestroyed();
 
-#ifndef OPENGL_ES2
-    OpenGLInstance::GLActiveTexture glActiveTexture = nullptr;
-    OpenGLInstance::GLGenBuffers glGenBuffers = nullptr;
-    OpenGLInstance::GLBindBuffer glBindBuffer = nullptr;
-    OpenGLInstance::GLBufferData glBufferData = nullptr;
-    OpenGLInstance::GLDeleteBuffers glDeleteBuffers = nullptr;
+#if !defined(QT_OPENGL_ES_2)
+    QOpenGLFunctions_1_5 m_gl15;
 #endif
-    OpenGLInstance::GLMapBufferRange glMapBufferRange = nullptr;
-    OpenGLInstance::GLMapBuffer glMapBuffer = nullptr;
-    OpenGLInstance::GLUnmapBuffer glUnmapBuffer = nullptr;
 
     bool vSync;
 
@@ -113,8 +104,13 @@ public:
     QStringList videoAdjustmentKeys;
     Frame videoFrame;
 
-    bool m_limited = false;
+    AVColorPrimaries m_colorPrimaries = AVCOL_PRI_UNSPECIFIED;
+    AVColorTransferCharacteristic m_colorTrc = AVCOL_TRC_UNSPECIFIED;
     AVColorSpace m_colorSpace = AVCOL_SPC_UNSPECIFIED;
+    float m_maxLuminance = 1000.0f;
+    float m_bitsMultiplier = 1.0f;
+    int m_depth = 8;
+    bool m_limited = false;
 
     std::unique_ptr<QOpenGLShaderProgram> shaderProgramVideo, shaderProgramOSD;
 
@@ -126,10 +122,12 @@ public:
     qint32 numPlanes;
     quint32 target;
 
+    bool m_canUse16bitTexture = false;
+
     quint32 pbo[4];
     bool hasPbo;
 
-    bool isPaused, isOK, hasImage, doReset, setMatrix, correctLinesize, canUseHueSharpness;
+    bool isPaused, isOK, hasImage, doReset, setMatrix, correctLinesize, m_gl3;
     int outW, outH, verticesIdx;
 
     QMPlay2OSDList osdList;
